@@ -1,5 +1,5 @@
 -- Common.hs: hOpenPGP-tools common functions
--- Copyright © 2012-2014  Clint Adams
+-- Copyright © 2012-2015  Clint Adams
 --
 -- vim: softtabstop=4:shiftwidth=4:expandtab
 --
@@ -20,6 +20,7 @@ module HOpenPGP.Tools.Common (
     banner
   , versioner
   , warranty
+  , prependAuto
   , keyMatchesFingerprint
   , keyMatchesEightOctetKeyId
   , keyMatchesExactUIDString
@@ -35,7 +36,6 @@ module HOpenPGP.Tools.Common (
   , tkUsingPKP
   , pUsingPKP
   , pUsingSP
-  , withReaderTK
   , tkGetUIDs
   , tkGetSubs
   , anyOrAll
@@ -55,28 +55,28 @@ import Data.Version (showVersion)
 import Codec.Encryption.OpenPGP.Fingerprint (eightOctetKeyID, fingerprint)
 import Codec.Encryption.OpenPGP.Types
 import Control.Lens ((^..))
-import Data.Char (toLower)
+import Data.Binary (put)
+import Data.Binary.Put (runPut)
+import qualified Data.ByteString.Lazy as BL
 import Data.Data.Lens (biplate)
-import Data.List (isInfixOf)
 import Data.Monoid ((<>))
-import Options.Applicative.Builder (help, infoOption, long, short)
-import Options.Applicative.Types (Parser)
+import Data.Text (Text)
+import qualified Data.Text as T
+import Options.Applicative.Builder (auto, help, infoOption, long, short)
+import Options.Applicative.Types (Parser, ReadM(..))
 import Text.PrettyPrint.ANSI.Leijen (Doc, (<+>), hardline, text)
 
 -- hmm --
-import qualified Data.ByteString as B
-import Data.Conduit.OpenPGP.Filter (Exp(..))
 import Data.Maybe (fromMaybe, mapMaybe)
-import Data.Serialize (runPut, put)
 import Codec.Encryption.OpenPGP.KeyInfo (pubkeySize)
 import Control.Error.Util (hush)
-import Control.Monad.Trans.Reader (ask, withReader, reader, Reader, runReader)
+import Control.Monad.Trans.Reader (ask, withReader, reader, Reader, runReader, ReaderT, local)
 
 
 banner :: String -> Doc
 {-# INLINE banner #-}
 banner name = text name <+> text "(hopenpgp-tools)" <+> text (showVersion version) <> hardline
-     <> text "Copyright (C) 2012-2014  Clint Adams"
+     <> text "Copyright (C) 2012-2015  Clint Adams"
 
 warranty :: String -> Doc
 {-# INLINE warranty #-}
@@ -91,17 +91,20 @@ versioner = infoOption (showVersion version) $
    <> short 'V'
    <> help "Show version information"
 
+prependAuto :: Read a => String -> ReadM a
+prependAuto s = ReadM (local (s++) (unReadM auto))
+
 keyMatchesFingerprint :: Bool -> TK -> TwentyOctetFingerprint -> Bool
 keyMatchesFingerprint = keyMatchesPKPred fingerprint
 
 keyMatchesEightOctetKeyId :: Bool -> TK -> Either String EightOctetKeyId -> Bool -- FIXME: refactor this somehow
 keyMatchesEightOctetKeyId = keyMatchesPKPred eightOctetKeyID
 
-keyMatchesExactUIDString :: String -> TK -> Bool
+keyMatchesExactUIDString :: Text -> TK -> Bool
 keyMatchesExactUIDString uidstr = any (==uidstr) . map fst . _tkUIDs
 
-keyMatchesUIDSubString :: String -> TK -> Bool
-keyMatchesUIDSubString uidstr = any (map toLower uidstr `isInfixOf`) . map (map toLower . fst) . _tkUIDs
+keyMatchesUIDSubString :: Text -> TK -> Bool
+keyMatchesUIDSubString uidstr = any (T.toLower uidstr `T.isInfixOf`) . map (T.toLower . fst) . _tkUIDs
 
 keyMatchesPKPred :: Eq a => (PKPayload -> a) -> Bool -> TK -> a -> Bool
 keyMatchesPKPred p False = (==) . p . fst . _tkKey
@@ -130,10 +133,7 @@ pkpGetFingerprint = fingerprint
 pkpGetEOKI :: PKPayload -> String
 pkpGetEOKI = either (const "UNKNOWN") show . eightOctetKeyID
 
-withReaderTK :: (TK -> c) -> Exp (Reader TK) c
-withReaderTK x = Lift x `Ap` MA ask
-
-tkGetUIDs :: TK -> [String]
+tkGetUIDs :: TK -> [Text]
 tkGetUIDs = map fst . _tkUIDs
 
 tkGetSubs :: TK -> [PKPayload]
@@ -143,6 +143,7 @@ tkGetSubs = mapMaybe (grabPKP . fst) . _tkSubs
         grabPKP (SecretSubkeyPkt p _) = Just p
         grabPKP _ = Nothing
 
+anyOrAll :: (Monad m, Monad m1) => ((a1 -> c) -> a -> ReaderT a m b) -> (m1 a1 -> c) -> ReaderT a m b
 anyOrAll aa op = ask >>= aa (op . return)
 
 anyReader :: Reader a Bool -> Reader [a] Bool
@@ -152,7 +153,7 @@ oGetTag :: Pkt -> Integer
 oGetTag = fromIntegral . pktTag
 
 oGetLength :: Pkt -> Integer
-oGetLength = fromIntegral . B.length . runPut . put     -- FIXME: this should be a length that makes sense
+oGetLength = fromIntegral . BL.length . runPut . put     -- FIXME: this should be a length that makes sense
 
 spGetSigVersion :: Pkt -> Maybe Integer
 spGetSigVersion (SignaturePkt s) = Just (sigVersion s)
