@@ -73,8 +73,8 @@ import Options.Applicative.Extra (customExecParser, helper)
 import Options.Applicative.Types (Parser)
 
 import System.IO (Handle, hFlush, stderr, hSetBuffering, BufferMode(..))
-import Text.PrettyPrint.ANSI.Leijen ((<+>), (</>), hardline, hPutDoc, list, putDoc, text)
-import Text.PrettyPrint.Free (pretty)
+import qualified Text.PrettyPrint.ANSI.Leijen as PPAL
+import Text.PrettyPrint.Free ((<+>), hardline, pretty, putDoc, text)
 
 grabMatchingKeysConduit :: MonadResource m => FilePath -> Bool -> Text -> Source m TK
 grabMatchingKeysConduit fp filt srch = CB.sourceFile fp $= conduitGet get $= conduitToTKsDropping $= (if filt then conduitTKFilter ufp else CL.filter matchAny)
@@ -166,7 +166,7 @@ listO homedir = Options
     <*> pure ""
     <*> pure ""
     where
-        targetHelp = helpDoc . Just $ text "target (which keys to output)*"
+        targetHelp = helpDoc . Just $ PPAL.text "target (which keys to output)*"
 
 graphO :: String -> Parser Options
 graphO homedir = Options
@@ -186,9 +186,9 @@ graphO homedir = Options
     <*> pure ""
     <*> pure ""
     where
-        ofhelp = helpDoc . Just $ text "output format" <> hardline <> list (map (text . show) ofchoices)
+        ofhelp = helpDoc . Just $ PPAL.text "output format" <> PPAL.hardline <> PPAL.list (map (PPAL.text . show) ofchoices)
         ofchoices = [minBound..maxBound] :: [GraphOutputFormat]
-        targetHelp = helpDoc . Just $ text "target (which keys to graph)*"
+        targetHelp = helpDoc . Just $ PPAL.text "target (which keys to graph)*"
 
 findPathsO :: String -> Parser Options
 findPathsO homedir = Options
@@ -208,9 +208,9 @@ findPathsO homedir = Options
     <*> argument str ( metavar "FROM-KEYS" <> fromHelp )
     <*> argument str ( metavar "TO-KEYS" <> toHelp )
     where
-        targetHelp = helpDoc . Just $ text "target (which keys to use in pathfinding)*"
-        fromHelp = helpDoc . Just $ text "from (which keys to use for the source of paths)*"
-        toHelp = helpDoc . Just $ text "to (which keys to use for the destinations of paths)*"
+        targetHelp = helpDoc . Just $ PPAL.text "target (which keys to use in pathfinding)*"
+        fromHelp = helpDoc . Just $ PPAL.text "from (which keys to use for the source of paths)*"
+        toHelp = helpDoc . Just $ PPAL.text "to (which keys to use for the destinations of paths)*"
 
 dispatch :: Command -> IO ()
 dispatch (CmdList o) = banner' stderr >> hFlush stderr >> doList o
@@ -232,14 +232,14 @@ cmd homedir = subparser
    <> command "list" (info ( CmdList <$> listO homedir) ( progDesc "list matching keys" <> footerDoc (Just foot) ))
     )
     where
-        foot = hardline <> text "*if --filter is not specified, this must be"
-               </> text "a fingerprint," </> text "an eight-octet key ID,"
-               </> text "or a substring of a UID (including an empty string)" <> hardline
-               <> text "if --filter is specified, it must be"
-               </> text "something in filter syntax (see source)."
+        foot = PPAL.hardline <> PPAL.text "*if --filter is not specified, this must be"
+               PPAL.</> PPAL.text "a fingerprint," PPAL.</> PPAL.text "an eight-octet key ID,"
+               PPAL.</> PPAL.text "or a substring of a UID (including an empty string)" <> PPAL.hardline
+               <> PPAL.text "if --filter is specified, it must be"
+               PPAL.</> PPAL.text "something in filter syntax (see source)."
 
 banner' :: Handle -> IO ()
-banner' h = hPutDoc h (banner "hkt" <> hardline <> warranty "hkt" <> hardline)
+banner' h = PPAL.hPutDoc h (banner "hkt" <> PPAL.hardline <> warranty "hkt" <> PPAL.hardline)
 
 doList :: Options -> IO ()
 doList o = do
