@@ -64,8 +64,9 @@ import Options.Applicative.Types (Parser)
 import System.IO (Handle, hFlush, stderr, stdin, stdout, hSetBuffering, BufferMode(..))
 import Data.Time.Locale.Compat (defaultTimeLocale)
 
-import Text.PrettyPrint.ANSI.Leijen (colon, green, hardline, hPutDoc, indent, linebreak, list, putDoc, red, text, yellow, (<+>), Doc)
-import Text.PrettyPrint.Free (pretty)
+import qualified Text.PrettyPrint.ANSI.Leijen as PPAL
+import Text.PrettyPrint.Free (colon, indent, linebreak, list, pretty, text, (<+>), Doc)
+import System.Console.Terminfo.PrettyPrint (green, red, yellow, displayLn, Effect)
 
 data KAS = KAS {
     pubkeyalgo :: Colored PubKeyAlgorithm
@@ -217,14 +218,14 @@ checkKey mpt key = (\x -> x { keyBestOf = populateBestOf x }) KeyReport {
         hasheds (SigV4 _ _ _ xs _ _ _) = xs
         hasheds _ = []
 
-prettyKeyReport :: POSIXTime -> TK -> Doc
+prettyKeyReport :: POSIXTime -> TK -> Doc Effect
 prettyKeyReport cpt key = do
  let keyReport = checkKey (Just cpt) key
  execWriter $ tell
    ( linebreak <> text "Key has potential validity:" <+> text (keyStatus keyReport)
-  <> linebreak <> text "Key has fingerprint:" <+> text (show (pretty (SpacedFingerprint (keyFingerprint keyReport))))
+  <> linebreak <> text "Key has fingerprint:" <+> pretty (SpacedFingerprint (keyFingerprint keyReport))
   <> linebreak <> text "Checking to see if key is OpenPGPv4:" <+> coloredToColor (text . show) (keyVer keyReport)
-  <> linebreak <> (\kas -> text "Checking to see if key is RSA or DSA (>= 2048-bit):" <+> coloredToColor (text . show) (pubkeyalgo kas) <+> coloredToColor (text . maybe "unknown" show) (pubkeysize kas)) (keyAlgorithmAndSize keyReport)
+  <> linebreak <> (\kas -> text "Checking to see if key is RSA or DSA (>= 2048-bit):" <+> coloredToColor pretty (pubkeyalgo kas) <+> coloredToColor (maybe (text "unknown") pretty) (pubkeysize kas)) (keyAlgorithmAndSize keyReport)
   <> linebreak <> text "Checking user-ID- and user-attribute-related items:"
   <> mconcat (map (uidtrip (keyCreationTime keyReport) . gottabeabetterway) (unFakeMap (keyUIDsAndUAts keyReport)))
   <> linebreak
@@ -236,10 +237,10 @@ prettyKeyReport cpt key = do
         coloredToColor f (Colored Nothing _ x) = f x
         uidtrip ts (u, ur)
            | null (uidRevocationStatus ur) = linebreak <> indent 2 (coloredToColor text (fmap T.unpack u)) <> colon
-          <> linebreak <> indent 4 (text "Self-sig hash algorithms" <> colon <+> (list . map (coloredToColor (text . show)) . uidSelfSigHashAlgorithms) ur)
-          <> linebreak <> indent 4 (text "Preferred hash algorithms" <> colon <+> mconcat (map ((linebreak <>) . indent 2 . coloredToColor (text . show)) (uidPreferredHashAlgorithms ur)))
-          <> linebreak <> indent 4 (text "Key expiration times" <> colon <+> mconcat (map ((linebreak <>) . indent 2 . coloredToColor list . fmap (map (text . keyExp ts))) (uidKeyExpirationTimes ur)))
-          <> linebreak <> indent 4 (text "Key usage flags" <> colon <+> mconcat (map ((linebreak <>) . indent 2 . coloredToColor (text . show . pretty . Set.toList)) (uidKeyUsageFlags ur)))
+          <> linebreak <> indent 4 (text "Self-sig hash algorithms" <> colon <+> (list . map (coloredToColor pretty) . uidSelfSigHashAlgorithms) ur)
+          <> linebreak <> indent 4 (text "Preferred hash algorithms" <> colon <+> mconcat (map (coloredToColor pretty) (uidPreferredHashAlgorithms ur)))
+          <> linebreak <> indent 4 (text "Key expiration times" <> colon <+> mconcat (map (coloredToColor list . fmap (map (text . keyExp ts))) (uidKeyExpirationTimes ur)))
+          <> linebreak <> indent 4 (text "Key usage flags" <> colon <+> (list . map (coloredToColor (pretty . Set.toList))) (uidKeyUsageFlags ur))
            | otherwise = linebreak <> indent 2 (coloredToColor text (fmap T.unpack u)) <> colon <+> text "[revoked]"
           <> linebreak <> indent 4 (text "Revocation code" <> colon <+> list (map (text . revocationCode) (uidRevocationStatus ur)))
           <> linebreak <> indent 4 (text "Revocation reason" <> colon <+> list (map (text . T.unpack . revocationReason) (uidRevocationStatus ur)))
@@ -271,7 +272,7 @@ lintO = LintOptions
        <> ofHelp
         )
     where
-        ofHelp = helpDoc . Just $ text "output format" <> hardline <> list (map (text . show) ofchoices)
+        ofHelp = helpDoc . Just $ PPAL.text "output format" <> PPAL.hardline <> PPAL.list (map (PPAL.text . show) ofchoices)
         ofchoices = [minBound..maxBound] :: [LintOutputFormat]
 
 
@@ -296,7 +297,7 @@ doLint o = do
     keys <- runResourceT $ CB.sourceHandle stdin $= conduitGet get $= conduitToTKsDropping $$ CL.consume
     output (lintOutputFormat o) cpt keys
     where
-        output Pretty cpt = mapM_ (putDoc . prettyKeyReport cpt)
+        output Pretty cpt = mapM_ (displayLn . prettyKeyReport cpt)
         output JSON cpt = mapM_ (BL.putStr . flip BL.append (BL.singleton 0x0a) . jsonReport cpt)
         output YAML cpt = mapM_ (B.putStr . yamlReport cpt)
 
@@ -315,7 +316,7 @@ doCanonicalize = do
         indepthsort = nub . sort . over (mapped._2) sort
 
 banner' :: Handle -> IO ()
-banner' h = hPutDoc h (banner "hokey" <> hardline <> warranty "hokey" <> hardline)
+banner' h = PPAL.hPutDoc h (banner "hokey" <> PPAL.hardline <> warranty "hokey" <> PPAL.hardline)
 
 sigissuer :: SignaturePayload -> Maybe EightOctetKeyId
 getIssuer :: SigSubPacketPayload -> Maybe EightOctetKeyId
