@@ -48,7 +48,7 @@ import System.IO (stdin, stderr, stdout, Handle, hFlush, hPutStrLn, hSetBufferin
 import Options.Applicative.Builder (argument, command, footerDoc, headerDoc, help, helpDoc, info, long, metavar, option, eitherReader, prefs, progDesc, showDefaultWith, showHelpOnError, str, strOption, subparser, value)
 import Options.Applicative.Extra (customExecParser, helper)
 import Options.Applicative.Types (Parser)
-import Text.PrettyPrint.ANSI.Leijen ((<+>), hardline, hPutDoc, list, softline, text)
+import qualified Text.PrettyPrint.ANSI.Leijen as PPAL
 import Text.PrettyPrint.Free (Pretty, pretty)
 
 data Command = DumpC DumpOptions | DeArmorC | ArmorC ArmoringOptions | FilterC FilteringOptions
@@ -125,7 +125,7 @@ doP = DumpOptions
     <> showDefaultWith (drop 4 . show)
     <> ofHelp )
     where
-        ofHelp = helpDoc . Just $ text "output format" <> hardline <> list (map (text . drop 4 . show) ofchoices)
+        ofHelp = helpDoc . Just $ PPAL.text "output format" <> PPAL.hardline <> PPAL.list (map (PPAL.text . drop 4 . show) ofchoices)
         ofchoices = [minBound..maxBound] :: [DumpOutputFormat]
 
 aoP :: Parser ArmoringOptions
@@ -133,13 +133,13 @@ aoP = ArmoringOptions
     <$> optional (strOption (long "comment" <> metavar "COMMENT" <> help "ASCII armor Comment field"))
     <*> option (eitherReader armorTypeReader) (long "armor-type" <> metavar "ARMORTYPE" <> armortypeHelp)
     where
-        armortypeHelp = helpDoc . Just $ text "ASCII armor type" <> softline <> list (map (text . fst) armorTypes)
+        armortypeHelp = helpDoc . Just $ PPAL.text "ASCII armor type" <> PPAL.softline <> PPAL.list (map (PPAL.text . fst) armorTypes)
 
 foP :: Parser FilteringOptions
 foP = FilteringOptions
     <$> argument str ( metavar "EXPRESSION" <> filterTargetHelp )
     where
-        filterTargetHelp = helpDoc . Just $ text "packet filter expression" <+> softline <> "see source for current syntax"
+        filterTargetHelp = helpDoc . Just $ PPAL.text "packet filter expression" PPAL.<+> PPAL.softline <> PPAL.text "see source for current syntax"
 
 dispatch :: Command -> IO ()
 dispatch c = (banner' stderr >> hFlush stderr) >> dispatch' c
@@ -163,7 +163,7 @@ cmd = subparser
   )
 
 banner' :: Handle -> IO ()
-banner' h = hPutDoc h (banner "hot" <> hardline <> warranty "hot" <> hardline)
+banner' h = PPAL.hPutDoc h (banner "hot" <> PPAL.hardline <> warranty "hot" <> PPAL.hardline)
 
 parseExpressions :: FilteringOptions -> FilterPredicates
 parseExpressions FilteringOptions{..} = RPFilterPredicate (parseE fExpression)
